import { SystemHealthAlertsBase } from '../foundation-system-health-alerts-base';
import type { ServicesStatusConfig, SystemHealthAlertsServiceItem as ServiceItem, SystemHealthAlertsServiceItemState as ServiceItemState, SystemHealthAlertsServiceHelperText as ServiceHelperText } from './main.types';
/**
 * The `SystemHealthAlertsService` component is designed to monitor and display the status of various services in real-time.
 * It leverages a connection to a backend datasource to receive updates about services status
 * and displays these updates to the user.
 *
 * @alpha
 */
export declare class SystemHealthAlertsService extends SystemHealthAlertsBase {
    closeTimeout: ServicesStatusConfig['closeTimeout'];
    autoClose: ServicesStatusConfig['autoClose'];
    maxMessages: ServicesStatusConfig['maxMessages'];
    maxMessagesChanged(): void;
    messageRestored: string;
    messageFailed: string;
    titleRestored: string;
    titleFailed: string;
    allMessages: ServiceItem[];
    allMessagesChanged(ignore: any, currentMessages: any): void;
    displayMessages: ServiceItem[];
    systemStatusServices: ServiceItem[];
    systemStatusServicesChanged(oldServices: ServiceItem[], newServices: ServiceItem[]): void;
    systemStatusChanged(ignore: any, newStatus: any): void;
    private updateDisplayMessages;
    private prepareServiceItem;
    private closeMessageHandler;
    emitCloseMessage(target: any, identifier: any): void;
    private replaceTextPlaceholders;
    getTextHelper: (textType: ServiceHelperText, type: ServiceItemState, item: ServiceItem) => string;
}
/**
 * ZeroSystemHealthAlertsService.
 *
 * @remarks
 * A zero version that pre-registers zero components and uses the zero design system.
 *
 * @example
 * ```ts
 * import { ZeroSystemHealthAlertsService } from '@genesislcap/foundation-system-health-alerts';
 * ...
 * ZeroSystemHealthAlertsService
 * ```
 *
 * @example Load the micro frontend on-demand
 * ```ts

 *   const { ZeroSystemHealthAlertsService } = await import('@genesislcap/foundation-system-health-alerts');
 *   return ZeroSystemHealthAlertsService;
 * },
 * ```
 *
 * @public
 */
export declare class ZeroSystemHealthAlertsService extends SystemHealthAlertsService {
    /**
     * @internal
     */
    connectedCallback(): Promise<void>;
    /**
     * @internal
     */
    protected loadRemotes(): Promise<void>;
}
//# sourceMappingURL=main.d.ts.map